isLight property
bool
get
isLight
Returns true when the active theme brightness is light.
Implementation
bool get isLight => theme.brightness == Brightness.light;
Returns true when the active theme brightness is light.
bool get isLight => theme.brightness == Brightness.light;