HorizontalListWithoutHeight class
- Inheritance
-
- Object
- DiagnosticableTree
- Widget
- StatelessWidget
- HorizontalListWithoutHeight
- Available extensions
Constructors
- HorizontalListWithoutHeight({required int itemCount, required IndexedWidgetBuilder itemBuilder, double? spacing, double? runSpacing, EdgeInsets? paddings, ScrollPhysics? physics, ScrollController? controller, bool reverse = false, WrapAlignment? wrapAlignment, WrapCrossAlignment? crossAxisAlignment, Key? key})
-
const
Properties
- controller → ScrollController?
-
final
- crossAxisAlignment → WrapCrossAlignment?
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- itemBuilder → IndexedWidgetBuilder
-
final
- itemCount → int
-
final
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- paddings → EdgeInsets?
-
final
- physics → ScrollPhysics?
-
final
- reverse → bool
-
final
- runSpacing → double?
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- sliverBox → SliverToBoxAdapter
-
Available on Widget, provided by the WidgetX extension
Wraps the widget in a SliverToBoxAdapter.no setter - spacing → double?
-
final
- wrapAlignment → WrapAlignment?
-
final
Methods
-
build(
BuildContext context) → Widget -
Describes the part of the user interface represented by this widget.
override
-
card(
{double? elevation, Color? color, Color? shadowColor, double? borderRadius, EdgeInsetsGeometry? margin}) → Card -
Available on Widget, provided by the WidgetX extension
Wraps the widget in a Card. -
center(
) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps the widget in a Center. -
cornerRadiusWithClipRRect(
double radius) → ClipRRect - Clips the widget with a uniform corner radius.
-
cornerRadiusWithClipRRectOnly(
{int bottomLeft = 0, int bottomRight = 0, int topLeft = 0, int topRight = 0}) → ClipRRect - Clips the widget with a per-corner radius.
-
createElement(
) → StatelessElement -
Creates a StatelessElement to manage this widget's location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
expanded(
{int flex = 1}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps the widget in an Expanded with the givenflex. -
flexible(
{int flex = 1, FlexFit fit = FlexFit.loose}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps the widget in a Flexible with the givenflexandfit. -
hero(
Object tag) → Hero -
Available on Widget, provided by the WidgetX extension
Wraps the widget in a Hero with the giventag. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
onTap(
Function? function, {BorderRadius? borderRadius, Color? splashColor, Color? hoverColor, Color? highlightColor, Color? focusColor, WidgetStateProperty< Color?> ? overlayColor}) → Widget -
Available on Widget, provided by the WidgetX extension
Wraps the widget in an InkWell that callsfunctionon tap. -
opacity(
double value) → Opacity -
Available on Widget, provided by the WidgetX extension
Wraps the widget in an Opacity.valueis clamped to 0.0–1.0. -
padding(
EdgeInsets padding) → Padding -
Available on Widget, provided by the WidgetX extension
Wraps the widget with the given EdgeInsets padding. -
paddingAll(
double value) → Padding -
Available on Widget, provided by the WidgetX extension
Wraps the widget with uniform padding ofvalueon all sides. -
paddingOnly(
{double left = 0, double top = 0, double right = 0, double bottom = 0}) → Padding - Wraps the widget with padding on individual sides.
-
paddingSymmetric(
{double horizontal = 0, double vertical = 0}) → Padding - Wraps the widget with symmetric padding.
-
rotate(
double angle) → Transform -
Available on Widget, provided by the WidgetX extension
Rotates the widget byangleradians. -
safeArea(
{bool top = true, bool bottom = true, bool left = true, bool right = true}) → SafeArea -
Available on Widget, provided by the WidgetX extension
Wraps the widget in a SafeArea. -
scale(
double factor) → Transform -
Available on Widget, provided by the WidgetX extension
Scales the widget uniformly byfactor. -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
tooltip(
String message) → Tooltip -
Available on Widget, provided by the WidgetX extension
Wraps the widget in a Tooltip withmessage. -
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
translate(
{double dx = 0, double dy = 0}) → Transform -
Available on Widget, provided by the WidgetX extension
Translates the widget by (dx,dy) logical pixels. -
visible(
bool isVisible, {Widget? defaultWidget}) → Widget -
Available on Widget, provided by the WidgetX extension
Shows or hides the widget based onisVisible. -
withHeight(
double height) → SizedBox -
Available on Widget, provided by the WidgetX extension
Returns a SizedBox with the givenheight. -
withSize(
{double? width, double? height}) → SizedBox -
Available on Widget, provided by the WidgetX extension
Returns a SizedBox constrained towidthandheight. -
withWidth(
double width) → SizedBox -
Available on Widget, provided by the WidgetX extension
Returns a SizedBox with the givenwidth.
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited